@@ -3,6 +3,7 @@ package utils
 import (
 	"bytes"
 	"encoding/xml"
+	"errors"
 	"fmt"
 	"github.com/PuerkitoBio/goquery"
 	"github.com/antchfx/xmlquery"
@@ -13,6 +14,7 @@ import (
 	"io"
 	"os"
 	"os/exec"
+	"regexp"
 	"strings"
 )
 
@@ -100,10 +102,7 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 			startTagClosed = false
 			level++
 		case xml.CharData:
-			str := string(typedToken)
-			if strings.TrimSpace(str) == "" {
-				str = ""
-			}
+			str := normalizeSpaces(string(typedToken), indent, level)
 			hasContent = str != ""
 			if hasContent && !startTagClosed {
 				_, _ = fmt.Fprint(writer, tagColor(">"))
@@ -161,7 +160,14 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 	return nil
 }
 
-func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode bool) error {
+func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode bool, nodeContent bool, indent string,
+	colors int) (errRes error) {
+	defer func() {
+		if err := recover(); err != nil {
+			errRes = errors.New(fmt.Sprintf("XPath error: %v", err))
+		}
+	}()
+
 	doc, err := xmlquery.ParseWithOptions(reader, xmlquery.ParserOptions{
 		Decoder: &xmlquery.DecoderOptions{
 			Strict: false,
@@ -173,17 +179,30 @@ func XPathQuery(reader io.Reader, writer io.Writer, query string, singleNode boo
 
 	if singleNode {
 		if n := xmlquery.FindOne(doc, query); n != nil {
-			_, _ = fmt.Fprintf(writer, "%s\n", strings.TrimSpace(n.InnerText()))
+			return printNodeContent(writer, n, nodeContent, indent, colors)
 		}
 	} else {
 		for _, n := range xmlquery.Find(doc, query) {
-			_, _ = fmt.Fprintf(writer, "%s\n", strings.TrimSpace(n.InnerText()))
+			err := printNodeContent(writer, n, nodeContent, indent, colors)
+			if err != nil {
+				return err
+			}
 		}
 	}
 
 	return nil
 }
 
+func printNodeContent(writer io.Writer, node *xmlquery.Node, withTags bool, indent string, colors int) error {
+	if withTags {
+		reader := strings.NewReader(node.OutputXML(true))
+		return FormatXml(reader, writer, indent, colors)
+	}
+
+	_, err := fmt.Fprintf(writer, "%s\n", strings.TrimSpace(node.InnerText()))
+	return err
+}
+
 func CSSQuery(reader io.Reader, writer io.Writer, query string) error {
 	doc, err := goquery.NewDocumentFromReader(reader)
 	if err != nil {
@@ -226,10 +245,7 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 
 		switch token {
 		case html.TextToken:
-			str := string(tokenizer.Text())
-			if strings.TrimSpace(str) == "" {
-				str = ""
-			}
+			str := normalizeSpaces(string(tokenizer.Text()), indent, level)
 			hasContent = str != ""
 			_, _ = fmt.Fprint(writer, str)
 		case html.StartTagToken, html.SelfClosingTagToken:
@@ -376,3 +392,23 @@ func escapeText(input string) (string, error) {
 
 	return result, nil
 }
+
+func normalizeSpaces(input string, indent string, level int) string {
+	if strings.TrimSpace(input) == "" {
+		input = ""
+	}
+
+	regexpHead, _ := regexp.Compile("^ *\n +")
+	if regexpHead.MatchString(input) {
+		input = strings.TrimLeft(input, " \n")
+		input = "\n" + strings.Repeat(indent, level) + input
+	}
+
+	regexpTail, _ := regexp.Compile("\n +$")
+	if regexpTail.MatchString(input) {
+		input = strings.TrimRight(input, " \n")
+		input += "\n" + strings.Repeat(indent, level-1)
+	}
+
+	return input
+}
